=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2007-08-23 15:03:26 +0000
+++ loggerhead/history.py	2007-09-07 08:09:52 +0000
@@ -51,6 +51,7 @@
 import bzrlib.diff
 import bzrlib.errors
 import bzrlib.progress
+import bzrlib.revision
 import bzrlib.textfile
 import bzrlib.tsort
 import bzrlib.ui
@@ -628,7 +629,8 @@
         try:
             for entry in entries:
                 if not entry.parents:
-                    old_tree = self._branch.repository.revision_tree("null:")
+                    old_tree = self._branch.repository.revision_tree(
+                        bzrlib.revision.NULL_REVISION)
                 else:
                     old_tree = trees[entry.parents[0].revid]
                 tree = trees[entry.revid]

=== modified file 'loggerhead/tests/test_filechangecache.py'
--- loggerhead/tests/test_filechangecache.py	2007-09-03 11:16:33 +0000
+++ loggerhead/tests/test_filechangecache.py	2007-09-07 08:09:52 +0000
@@ -1,9 +1,9 @@
-from loggerhead.changecache import FileChangeCache
+"""Tests for the FileChangeCache in loggerhead.changecache."""
 
-import random
 import shutil
 import tempfile
 
+from loggerhead.changecache import FileChangeCache
 
 class MockEntry:
     def __init__(self, revid):
@@ -23,8 +23,8 @@
 
 class TestFileChangeCache(object):
 
-    # there are so i can run it with py.test and take advantage of the
-    # error reporting...
+    # setup_method and teardown_method are so i can run the tests with
+    # py.test and take advantage of the error reporting.
     def setup_method(self, meth):
         self.setUp()
 
@@ -32,64 +32,64 @@
         self.tearDown()
 
     def setUp(self):
-        self.cache_folder = tempfile.mkdtemp()
+        self.cache_folders = []
 
     def tearDown(self):
-        shutil.rmtree(self.cache_folder)
+        for folder in self.cache_folders:
+            shutil.rmtree(folder)
+
+
+    def makeHistoryAndEntriesForRevids(self, revids, fill_cache_with=[]):
+        cache_folder = tempfile.mkdtemp()
+        self.cache_folders.append(cache_folder)
+        self.history = MockHistory()
+        self.cache = FileChangeCache(self.history, cache_folder)
+
+        self.entries = [MockEntry(revid) for revid in revids]
+
+        self.cache.get_file_changes([entry for entry in self.entries
+                                     if entry.revid in fill_cache_with])
+        self.history.fetched_revids.clear()
+
 
     def test_empty_cache(self):
         """An empty cache passes all the revids through to the history object.
         """
-
-        history = MockHistory()
-        cache = FileChangeCache(history, self.cache_folder)
-
         revids = ['a', 'b']
-        entries = [MockEntry(revid) for revid in revids]
-
-        result = cache.get_file_changes(entries)
-
-        assert result == revids
-
-        assert history.fetched_revids == set(revids)
+        self.makeHistoryAndEntriesForRevids(revids)
+
+        result = self.cache.get_file_changes(self.entries)
+
+        assert result == self.revids
+        assert self.history.fetched_revids == set(self.revids)
 
     def test_full_cache(self):
         """A full cache passes none of the revids through to the history
         object.
         """
-
-        history = MockHistory()
-        cache = FileChangeCache(history, self.cache_folder)
-
         revids = ['a', 'b']
-        entries = [MockEntry(revid) for revid in revids]
-
-        # One call to fill the cache
-        cache.get_file_changes(entries)
-        history.fetched_revids.clear()
-
-        result = cache.get_file_changes(entries)
+        self.makeHistoryAndEntriesForRevids(revids, fill_cache_with=revids)
+
+        result = self.cache.get_file_changes(self.entries)
+
         assert result == revids
-
-        assert history.fetched_revids == set()
+        assert self.history.fetched_revids == set()
 
     def test_partial_cache(self):
         """A partially full cache passes some of the revids through to the
         history object, and preserves the ordering of the argument list.
         """
-
-        history = MockHistory()
-        cache = FileChangeCache(history, self.cache_folder)
-
-        revids = [chr(ord('a') + i) for i in range(20)]
-        entries = [MockEntry(revid) for revid in revids]
-
-        some_entries = random.sample(entries, len(entries)/2)
-        cache.get_file_changes(some_entries)
-        history.fetched_revids.clear()
-
-        result = cache.get_file_changes(entries)
-        assert result == revids
-
-        assert history.fetched_revids \
-               == set(revids) - set([e.revid for e in some_entries])
+        # To test the preservation of argument order code, we put the uncached
+        # revid at the beginning, middle and then end of the list of revids
+        # being asked for.
+        for i in range(3):
+            cached_revids = ['a', 'b']
+            revids = cached_revids[:]
+            revids.insert(i, 'uncached')
+            self.makeHistoryAndEntriesForRevids(
+                revids, fillCacheWith=cached_revids)
+
+            result = self.cache.get_file_changes(self.entries)
+            assert result == revids
+
+            assert self.history.fetched_revids == set(['uncached'])

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2007-06-26 19:23:08 +0000
+++ loggerhead/tests/test_simple.py	2007-09-07 08:09:52 +0000
@@ -23,9 +23,8 @@
 
 class BasicTests(object):
 
-
-    # there are so i can run it with py.test and take advantage of the
-    # error reporting...
+    # setup_method and teardown_method are so i can run the tests with
+    # py.test and take advantage of the error reporting.
     def setup_method(self, meth):
         self.setUp()
 

